@@ -32,6 +32,37 @@ def make_module_from_function(funcobj):
     return module
 
 
+def copy_markinfo(module, funcobj):
+    from _pytest.mark import MarkInfo
+
+    marks = {}
+    for name, val in funcobj.__dict__.items():
+        if isinstance(val, MarkInfo):
+            marks[name] = val
+
+    for obj in module.__dict__.values():
+        if isinstance(obj, types.FunctionType):
+            for name, mark in marks.items():
+                setattr(obj, name, mark)
+
+
+def merge_pytestmark(module, parentobj):
+    try:
+        pytestmark = parentobj.pytestmark
+        if not isinstance(pytestmark, list):
+            pytestmark = [pytestmark]
+        try:
+            if isinstance(module.pytestmark, list):
+                pytestmark.extend(module.pytestmark)
+            else:
+                pytestmark.append(module.pytestmark)
+        except AttributeError:
+            pass
+        module.pytestmark = pytestmark
+    except AttributeError:
+        pass
+
+
 class DescribeBlock(pytest.Module):
     """Module-like object representing the scope of a describe block"""
 
@@ -45,17 +76,14 @@ class DescribeBlock(pytest.Module):
 
     def _importtestmodule(self):
         """Import a describe block as if it was a module"""
-        return make_module_from_function(self.funcobj)
+        module = make_module_from_function(self.funcobj)
+        copy_markinfo(module, self.funcobj)
+        merge_pytestmark(module, self.parent.obj)
+        return module
 
     def funcnamefilter(self, name):
         """Treat all nested functions as tests, without requiring the 'test_' prefix"""
-        if name.startswith('_'):
-            return False
-        for prefix in self.config.getini('describe_prefixes'):
-            if name.startswith(prefix):
-                return False
-        else:
-            return True
+        return not name.startswith('_')
 
     def classnamefilter(self, name):
         """Don't allow test classes inside describe"""
@@ -67,15 +95,13 @@ class DescribeBlock(pytest.Module):
 
 
 def pytest_pycollect_makeitem(__multicall__, collector, name, obj):
-    res = __multicall__.execute()
-    if res is not None:
-        return res
-
     if isinstance(obj, types.FunctionType):
         for prefix in collector.config.getini('describe_prefixes'):
             if obj.__name__.startswith(prefix):
                 return DescribeBlock(obj, collector.fspath, collector)
 
+    return __multicall__.execute()
+
 
 def pytest_addoption(parser):
     parser.addini("describe_prefixes", type="args", default=("describe",),
